==> dmn-drools-springboot-metrics-1.17.0.Final-sources.jar: org/kie/kogito/examples/Rules471B42E068A21F8D5BEF529A54AE3B27.java <==
package org.kie.kogito.examples;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;

public abstract class Rules471B42E068A21F8D5BEF529A54AE3B27 implements org.drools.model.Model {

    public final static java.time.format.DateTimeFormatter DATE_TIME_FORMATTER = new java.time.format.DateTimeFormatterBuilder().parseCaseInsensitive().appendPattern(org.drools.core.util.DateUtils.getDateFormatMask()).toFormatter(java.util.Locale.ENGLISH);

    @Override
    public String getName() {
        return "org.kie.kogito.examples";
    }

    @Override
    public java.util.List<org.drools.model.EntryPoint> getEntryPoints() {
        return java.util.Arrays.asList(D.entryPoint("strings"));
    }

    @Override
    public java.util.List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public java.util.List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    public static final org.drools.model.Global<org.kie.kogito.rules.DataStore> var_strings = D.globalOf(org.kie.kogito.rules.DataStore.class,
                                                                                                         "org.kie.kogito.examples",
                                                                                                         "strings");

    public static final org.drools.model.Query0Def queryDef_hello = D.query("org.kie.kogito.examples",
                                                                            "hello");

    java.util.List<org.drools.model.Global> globals = new java.util.ArrayList<>();

    java.util.List<org.drools.model.TypeMetaData> typeMetaDatas = java.util.Collections.emptyList();

    {
        globals.add(var_strings);
    }
}

==> dmn-drools-springboot-metrics-1.22.0.Final-sources.jar: org/kie/kogito/examples/Rules471B42E068A21F8D5BEF529A54AE3B27.java <==
package org.kie.kogito.examples;

import org.drools.modelcompiler.dsl.pattern.D;
import org.drools.model.Index.ConstraintType;

public abstract class Rules471B42E068A21F8D5BEF529A54AE3B27 implements org.drools.model.Model {

    public final static java.time.format.DateTimeFormatter DATE_TIME_FORMATTER = new java.time.format.DateTimeFormatterBuilder().parseCaseInsensitive().appendPattern(org.drools.util.DateUtils.getDateFormatMask()).toFormatter(java.util.Locale.ENGLISH);

    @Override
    public String getName() {
        return "org.kie.kogito.examples";
    }

    @Override
    public java.util.List<org.drools.model.EntryPoint> getEntryPoints() {
        return java.util.Arrays.asList(D.entryPoint("strings"));
    }

    @Override
    public java.util.List<org.drools.model.Global> getGlobals() {
        return globals;
    }

    @Override
    public java.util.List<org.drools.model.TypeMetaData> getTypeMetaDatas() {
        return typeMetaDatas;
    }

    public static final org.drools.model.Global<org.kie.kogito.rules.DataStore> var_strings = D.globalOf(org.kie.kogito.rules.DataStore.class,
                                                                                                         "org.kie.kogito.examples",
                                                                                                         "strings");

    public static final org.drools.model.Query0Def queryDef_hello = D.query("org.kie.kogito.examples",
                                                                            "hello");

    java.util.List<org.drools.model.Global> globals = new java.util.ArrayList<>();

    java.util.List<org.drools.model.TypeMetaData> typeMetaDatas = java.util.Collections.emptyList();

    {
        globals.add(var_strings);
    }
}
